@@ -44,14 +44,19 @@ class BackupHistory {
                 throw new Exception("Missing required field: $field");
             }
         }
-        
-        $fields = ['target_id', 'user', 'backup_type', 'backup_name', 'backup_path', 
+
+        // Set default status if not provided
+        if (!isset($data['status'])) {
+            $data['status'] = 'pending';
+        }
+
+        $fields = ['target_id', 'user', 'backup_type', 'backup_name', 'backup_path',
                    'backup_size', 'status', 'metadata'];
         $placeholders = array_fill(0, count($fields), '?');
-        
+
         $sql = "INSERT INTO backup_history (" . implode(', ', $fields) . ") VALUES (" . implode(', ', $placeholders) . ")";
         $stmt = $this->db->prepare($sql);
-        
+
         $values = [];
         foreach ($fields as $field) {
             if ($field === 'metadata' && isset($data[$field])) {
@@ -60,13 +65,13 @@ class BackupHistory {
                 $values[] = $data[$field] ?? null;
             }
         }
-        
+
         if ($stmt->execute($values)) {
             $this->id = $this->db->lastInsertId();
             $this->load($this->id);
             return true;
         }
-        
+
         return false;
     }
     
