@@ -468,18 +468,65 @@ class PowerDNSIntegration {
      * @return string Server IP address
      */
     private function getServerIP() {
-        // Try to get from environment or config
-        $server_ip = $_SERVER['SERVER_ADDR'] ?? '127.0.0.1';
+        // First check server settings for configured IP
+        $server_settings = $this->getServerSettings();
+        if (!empty($server_settings['server_ip'])) {
+            return $server_settings['server_ip'];
+        }
         
-        // If it's localhost, try to get external IP
-        if ($server_ip === '127.0.0.1' || $server_ip === '::1') {
-            // Try to get from network interface
-            $output = shell_exec("ip route get 8.8.8.8 | awk '{print $7}' | head -1");
-            if ($output) {
+        // Try multiple methods to get the server IP
+        $server_ip = null;
+        
+        // Method 1: Try primary network interface
+        $output = shell_exec("ip route get 8.8.8.8 2>/dev/null | awk '{print $7}' | head -1");
+        if ($output && trim($output) !== '') {
+            $server_ip = trim($output);
+        }
+        
+        // Method 2: Try getting primary interface IP
+        if (!$server_ip) {
+            $output = shell_exec("hostname -I 2>/dev/null | awk '{print $1}'");
+            if ($output && trim($output) !== '') {
                 $server_ip = trim($output);
             }
         }
         
+        // Method 3: Try SERVER_ADDR environment variable
+        if (!$server_ip) {
+            $server_ip = $_SERVER['SERVER_ADDR'] ?? null;
+        }
+        
+        // Method 4: Try getting from primary network interface directly
+        if (!$server_ip || $server_ip === '127.0.0.1' || $server_ip === '::1') {
+            $output = shell_exec("ip -4 addr show scope global | grep inet | head -1 | awk '{print $2}' | cut -d/ -f1 2>/dev/null");
+            if ($output && trim($output) !== '') {
+                $server_ip = trim($output);
+            }
+        }
+        
+        // Method 5: For development/test environments, check common internal ranges
+        if (!$server_ip || $server_ip === '127.0.0.1') {
+            // Check for common internal IP patterns
+            $interfaces = shell_exec("ip addr show 2>/dev/null | grep 'inet ' | grep -v '127.0.0.1' | awk '{print $2}' | cut -d/ -f1");
+            if ($interfaces) {
+                $ips = explode("\n", trim($interfaces));
+                foreach ($ips as $ip) {
+                    $ip = trim($ip);
+                    // Prefer 192.168.x.x, 10.x.x.x, or 172.16-31.x.x ranges for internal networks
+                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) && $ip !== '127.0.0.1') {
+                        $server_ip = $ip;
+                        break;
+                    }
+                }
+            }
+        }
+        
+        // Final fallback
+        if (!$server_ip) {
+            $server_ip = '127.0.0.1';
+            error_log("PowerDNS: Warning - Could not determine server IP, using localhost");
+        }
+        
         return $server_ip;
     }
     
